@@ -32,7 +32,9 @@ def _order_upload_keys(fields, keys):
 
 
 def format_request_body(fields):
-    if set(fields.keys()).issubset(set(PRESERVED_ORDER_V1)):
+    if len(fields.keys()) == 0:
+        return fields
+    elif set(fields.keys()).issubset(set(PRESERVED_ORDER_V1)):
         return _order_upload_keys(fields, PRESERVED_ORDER_V1)
     elif set(fields.keys()).issubset(set(PRESERVED_SIGNATURE_V4)):
         return _order_upload_keys(fields, PRESERVED_SIGNATURE_V4)
@@ -50,19 +52,40 @@ def upload(destination, file, progress_bar=False, filename='features_backup.rcdb
     :return:
     """
     url = destination["url"]
-    fields = format_request_body(destination['fields'])
 
-    fields["file"] = (filename, file)
-    encoder = MultipartEncoder(fields=fields)
-    if not progress_bar:
-        return requests.post(
-            url, data=encoder, headers={"Content-Type": encoder.content_type}
-        )
+    provider = destination.get('provider', 'aws-s3')
+    if provider == 'aws-s3':
+        fields = destination.get('fields', None)
+        if fields is None:
+            fields = dict()
 
-    with ProgressBar(total=encoder.len, unit="bytes", unit_scale=True, leave=False) as bar:
-        monitor = MultipartEncoderMonitor(encoder, lambda monitor: bar.update_to(monitor.bytes_read))
-        return requests.post(
-            url, data=monitor, headers={"Content-Type": encoder.content_type}
+        # apply sorting required for the AWS
+        fields = format_request_body(fields)
+
+        fields["file"] = (filename, file)
+        encoder = MultipartEncoder(fields=fields)
+
+        headers = {"Content-Type": encoder.content_type}
+        headers.update(destination.get('headers', {}))
+
+        if not progress_bar:
+            return requests.post(
+                url, data=encoder, headers=headers
+            )
+
+        with ProgressBar(total=encoder.len, unit="bytes", unit_scale=True, leave=False) as bar:
+            monitor = MultipartEncoderMonitor(
+                encoder,
+                lambda monitor: bar.update_to(monitor.bytes_read)
+            )
+            return requests.post(
+                url, data=monitor, headers=headers
+            )
+    elif provider == 'azure-blob':
+        return requests.put(
+            url,
+            data=file,
+            headers=destination.get('headers'),
         )
 
 
