@@ -151,7 +151,7 @@ def create_processing_action(ctx, input_type, store, store_planogram, aisle, sec
         lens_used=lens_used
     )
     if ctx.verbose:
-        click.echo(response, )
+        click.echo(json.dumps(response, indent=2))
     click.echo(response['id'])
 
 
@@ -775,12 +775,12 @@ def processing_action_realogram_report(ctx, concurrency, drop_duplicates, target
             'position',
             'left', 'top', 'right', 'bottom',
             'shelf_bay_id',
-        ], dtype=object)
+        ], dtype=str)
 
         df_realogram_pac['processing_action'] = processing_action['id']
         df_realogram_pac['store_id'] = processing_action['store_id']
         df_realogram_pac['store_name'] = processing_action['store_name']
-        df_realogram_pac['store_number'] = processing_action['store']['store_number']
+        df_realogram_pac['store_number'] = processing_action['store']['custom_id']
         df_realogram_pac['created'] = processing_action['created']
 
         df_realogram_pac = df_realogram_pac.merge(
@@ -798,7 +798,7 @@ def processing_action_realogram_report(ctx, concurrency, drop_duplicates, target
         df_oos_processing_action['processing_action'] = processing_action['id']
         df_oos_processing_action['store_id'] = processing_action['store_id']
         df_oos_processing_action['store_name'] = processing_action['store_name']
-        df_oos_processing_action['store_number'] = processing_action['store'].get('store_number')
+        df_oos_processing_action['store_number'] = processing_action['store'].get('custom_id')
         df_oos_processing_action['created'] = processing_action['created']
         df_oos_processing_action = df_oos_processing_action.merge(
             df_bay_reports, left_on='shelf_bay_id', right_on='id'
@@ -812,8 +812,11 @@ def processing_action_realogram_report(ctx, concurrency, drop_duplicates, target
             'download_report_url',
         ], index=['id'], dtype=object)
         df_pac['user'] = processing_action['user'].get('username', '')
-        df_pac['compliance_rate'] = processing_action['compliance_rates'].get('compliance', '0')
-        df_pac['store_number'] = processing_action['store'].get('store_number')
+        try:
+            df_pac['compliance_rate'] = processing_action['compliance_rates'].get('compliance', '0')
+        except:
+            df_pac['compliance_rate'] = 0
+        df_pac['store_number'] = processing_action['store'].get('custom_id')
         df_scans = df_scans.append(df_pac)
 
     # if drop_duplicates:
