@@ -3,6 +3,10 @@ from .base import ReboticsBaseProvider, remote_service, ProviderHTTPClientExcept
 
 
 class AdminProvider(ReboticsBaseProvider):
+    @remote_service('/version/')
+    def version(self):
+        return self.session.get()
+
     @remote_service('/admin/', json=False)
     def admin_ping(self, **kwargs):
         return self.session.get()
